HTTPOperationBinding

Struct HTTPOperationBinding 

pub struct HTTPOperationBinding {
    pub typ: String,
    pub method: Option<String>,
    pub query: Option<Schema>,
    pub binding_version: Option<String>,
}
Examples

channels:
  /employees:
    subscribe:
      bindings:
        http:
          type: request
          method: GET
          query:
            type: object
            required:
              - companyId
            properties:
              companyId:
                type: number
                minimum: 1
                description: The Id of the company.
            additionalProperties: false
          bindingVersion: '0.1.0'

Fields

typ: String

Required. Type of operation. Its value MUST be either request or response.

method: Option<String>

When type is request, this is the HTTP method, otherwise it MUST be ignored. Its value MUST be one of GET, POST, PUT, PATCH, DELETE, HEAD, OPTIONS, CONNECT, and TRACE.

query: Option<Schema>

A Schema object containing the definitions for each query parameter. This schema MUST be of type object and have a properties key.

binding_version: Option<String>

The version of this binding. If omitted, “latest” MUST be assumed.